#!/bin/sh

echo "Cheese log:"
cat $HOME/.gnome2/cheese/log.txt
